import {TestBed} from '@angular/core/testing';
import {ConfigurationService} from './configuration.service';
import {HttpClientTestingModule} from "@angular/common/http/testing";
import {of} from "rxjs";

export class FakeEnvService {
  configUrl = 'http://localhost:4200/VlassMngr/services/configuration';
}

describe('ConfigurationService', () => {

  let httpClientSpy: { get: jasmine.Spy };
  let configurationService: ConfigurationService;

  beforeEach(() => {
    TestBed.configureTestingModule({
      imports: [HttpClientTestingModule],
      providers: [ConfigurationService]
    });
    httpClientSpy = jasmine.createSpyObj('HttpClient', ['get']);
    configurationService = new ConfigurationService(<any>httpClientSpy, <any>FakeEnvService);
  });

  it('should be created', () => {
    const service: ConfigurationService = TestBed.get(ConfigurationService);
    expect(service).toBeTruthy();
  });

  it('should fetch configuration from endpoint with one call and cache', () => {
    const configResponse = {
      dryrun: "false",
      rootDataDirectory: "/lustre/aoc/cluster/pipeline/vlass_test/spool",
      url: "http://localhost:4200/VlassMngr",
      weblogbaseurl: "http://webtest.aoc.nrao.edu/",
      projectcode: "VLASS1.1",
      wsurl: "ws://localhost:8081/VlassMngr/changes",
      currentepoch: "1"
    };

    httpClientSpy.get.and.returnValue(of(configResponse));

    configurationService.getSettings().then(response => {
      expect(response).toEqual(configResponse, 'get config from http');
      expect(httpClientSpy.get).toHaveBeenCalledTimes(1);
      expect(configurationService.config).toEqual(configResponse, 'get conig()');
    }, fail);
  });
});
